@@ -14,25 +14,20 @@ __email__ = "tpovedatd@gmail.com"
 
 
 import os
-import re
 import sys
 import time
-import locale
 import logging
 import tempfile
 import datetime
 import importlib
 import traceback
 import webbrowser
-from collections import OrderedDict
-
-import six
 
 from Qt.QtCore import *
 from Qt.QtWidgets import *
 
-from tpPyUtils import python, decorators, osplatform, fileio, path as path_utils, folder as folder_utils
-import tpDccLib as tp
+import tpDcc as tp
+from tpDcc.libs.python import python, osplatform, fileio, path as path_utils, folder as folder_utils
 
 if python.is_python2():
     from urllib2 import quote
@@ -43,34 +38,32 @@ else:
 
 import artellapipe
 from artellapipe.libs import artella as artella_lib
-from artellapipe.libs.artella.core import artellalib, artellaclasses
-from artellapipe.core import defines, config, node, sequence, shot
-from artellapipe.utils import resource
+from artellapipe.libs.artella.core import artellalib
+from artellapipe.core import defines
 
 LOGGER = logging.getLogger()
 
 
 class ArtellaProject(object):
-
-    SHELF_CLASS = tp.Shelf
-    SEQUENCE_CLASS = sequence.ArtellaSequence
-    SHOT_CLASS = shot.ArtellaShot
-    ASSET_NODE_CLASS = node.ArtellaAssetNode
-
     def __init__(self, name, settings=None):
         super(ArtellaProject, self).__init__()
 
         self._tray = None
 
-        self._production_info = None
-        self._sequences = list()
-        self._shots = list()
-
-        # To make sure that all variables are properly initialized we must call init_config first
         clean_name = self._get_clean_name(name)
-        self._config = config.ArtellaConfiguration(
-            project_name=clean_name,
+
+        # Register project configurations
+        try:
+            project_config_mod = importlib.import_module('{}.config'.format(clean_name))
+            tp.ConfigsMgr().register_package_configs(
+                clean_name, os.path.dirname(project_config_mod.__file__))
+        except RuntimeError:
+            artellapipe.logger.warning('No Configuration Module found for project: {}'.format(clean_name))
+
+        self._config = tp.ConfigsMgr().get_config(
             config_name='artellapipe-project',
+            package_name=clean_name,
+            root_package_name='artellapipe',
             environment=os.environ.get('{}_env'.format(self._get_clean_name(name)), 'DEVELOPMENT'),
             config_dict={
                 'title': clean_name.title(),
@@ -130,7 +123,7 @@ class ArtellaProject(object):
         :return: str
         """
 
-        artella_production_folder = artellalib.config.get('server', {}).get('production_folder')
+        artella_production_folder = self.get_production_folder()
         if not artella_production_folder:
             LOGGER.warning('Impossible to retrieve Artella project ID!')
             return None
@@ -153,7 +146,16 @@ class ArtellaProject(object):
         :return: QIcon
         """
 
-        return resource.ResourceManager().icon(self.icon_name, theme=self.icon_resources_folder)
+        return tp.ResourcesMgr().icon(self.icon_name, theme=self.icon_resources_folder)
+
+    @property
+    def thumb_icon(self):
+        """
+        Returns thumb icon for the project
+        :return: QIcon
+        """
+
+        return tp.ResourcesMgr().icon(self.get_clean_name(), category='images', key='project', theme=None)
 
     @property
     def tray_icon(self):
@@ -162,7 +164,7 @@ class ArtellaProject(object):
         :return: QIcon
         """
 
-        return resource.ResourceManager().icon(self.tray_icon_name, key='project')
+        return tp.ResourcesMgr().icon(self.tray_icon_name, key='project')
 
     @property
     def shelf_icon(self):
@@ -171,7 +173,7 @@ class ArtellaProject(object):
         :return: QIcon
         """
 
-        return resource.ResourceManager().icon(self.shelf_icon_name, theme=None, key='project')
+        return tp.ResourcesMgr().icon(self.shelf_icon_name, theme=None, key='project')
 
     @property
     def tray(self):
@@ -195,17 +197,21 @@ class ArtellaProject(object):
         self.update_paths()
         self.set_environment_variables()
         self.create_shelf()
-        self.create_menu()
         self._tray = self.create_tray()
         self.create_names_manager()
         self.create_files_manager()
         self.create_assets_manager()
         self.create_tags_manager()
         self.create_shaders_manager()
+        self.create_sequences_manager()
         self.create_shots_manager()
+        self.create_tasks_manager()
+        self.create_media_manager()
         self.create_playblasts_manager()
         self.create_pyblish_manager()
-        self.create_shots_manager()
+        self.create_dependencies_manager()
+        self.create_casting_manager()
+        self.create_slack_manager()
         self.create_production_tracker()
         self.update_project()
         self._update_dcc_ui()
@@ -228,6 +234,22 @@ class ArtellaProject(object):
         current_environment = self.get_environment()
         return not current_environment or current_environment == 'DEVELOPMENT'
 
+    def get_toolsets_paths(self):
+        """
+        Returns path where project toolsets are located
+        :return: list(str)
+        """
+
+        return list()
+
+    def get_resources_paths(self):
+        """
+        Returns path where project resources are located
+        :return: dict(str, list(str), dict containing resources keys and resources paths
+        """
+
+        return dict()
+
     def get_tag(self):
         """
         Returns the current deployed tag of the project
@@ -256,8 +278,6 @@ class ArtellaProject(object):
         :return: str
         """
 
-        print('bjblblbl')
-
         try:
             pkg_loader = loader.find_loader('{}.config'.format(self._get_clean_name(self.name)))
         except ImportError:
@@ -363,7 +383,9 @@ class ArtellaProject(object):
         :return: str
         """
 
-        data_path = os.path.join(os.getenv('APPDATA'), self.get_clean_name())
+        import appdirs
+
+        data_path = appdirs.user_data_dir(self.get_clean_name())
         if not os.path.isdir(data_path):
             os.makedirs(data_path)
 
@@ -382,7 +404,7 @@ class ArtellaProject(object):
         Creates and initializes Artella project logger
         """
 
-        from tpPyUtils import log as log_utils
+        from tpDcc.libs.python import log as log_utils
 
         log_path = self.get_data_path()
         if not os.path.exists(log_path):
@@ -444,11 +466,19 @@ class ArtellaProject(object):
                     self.name.title()))
             LOGGER.error('{} | {}'.format(e, traceback.format_exc()))
 
-        icons_paths = resource.ResourceManager().get_resources_paths()
-        # icons_paths = [
-        #     artellapipe.resource.RESOURCES_FOLDER,
-        #     self.resource.RESOURCES_FOLDER
-        # ]
+        temp_env_var = self.get_temporary_environment_variable()
+        os.environ[temp_env_var] = tempfile.gettempdir()
+        project_temp_folder = path_utils.clean_path(
+            os.path.join(tempfile.gettempdir(), '{}_temp'.format(self.get_clean_name())))
+        if not os.path.isdir(project_temp_folder):
+            try:
+                os.makedirs(project_temp_folder)
+            except Exception as exc:
+                LOGGER.warning('Impossible to create temporally folder for project "{}"'.format(self.get_clean_name()))
+        if os.path.isdir(project_temp_folder):
+            os.environ[temp_env_var] = project_temp_folder
+
+        icons_paths = tp.ResourcesMgr().get_resources_paths()
 
         current_paths = list()
         if os.environ.get('XBMLANGPATH'):
@@ -467,6 +497,12 @@ class ArtellaProject(object):
                     else:
                         os.environ['XBMLANGPATH'] = os.environ.get('XBMLANGPATH') + ';' + root
 
+        slack_token = self.config.get('slack_token', '')
+        slack_channel = self.config.get('slack_channel', '')
+        if slack_token and slack_channel:
+            os.environ['{}_SLACK_API_TOKEN'.format(self.get_clean_name().upper())] = 'xoxb-{}'.format(slack_token)
+            os.environ['{}_SLACK_CHANNEL'.format(self.get_clean_name().upper())] = slack_channel
+
         LOGGER.debug('=' * 100)
         LOGGER.debug("{} Pipeline initialization completed!".format(self.name))
         LOGGER.debug('=' * 100)
@@ -487,19 +523,6 @@ class ArtellaProject(object):
 
         return shelf_manager
 
-    def create_menu(self):
-        """
-        Creates Artella Project menu
-        """
-
-        if tp.Dcc == tp.Dccs.Unknown:
-            return False
-
-        menu_manager = artellapipe.MenuMgr()
-        menu_manager.set_project(self)
-
-        return menu_manager
-
     def create_names_manager(self):
         """
         Creates instance of the assets manager used by the project
@@ -558,6 +581,17 @@ class ArtellaProject(object):
 
         return shaders_manager
 
+    def create_sequences_manager(self):
+        """
+        Creates instance of the sequences manager used by the project
+        :return: ArtellaSequencesManager
+        """
+
+        sequences_manager = artellapipe.SequencesMgr()
+        sequences_manager.set_project(self)
+
+        return sequences_manager
+
     def create_shots_manager(self):
         """
         Creates instance of the shots manager used by the project
@@ -569,6 +603,28 @@ class ArtellaProject(object):
 
         return shots_manager
 
+    def create_tasks_manager(self):
+        """
+        Creates instance of the tasks manager used by the project
+        :return: ArtellaShotsManager
+        """
+
+        tasks_manager = artellapipe.TasksMgr()
+        tasks_manager.set_project(self)
+
+        return tasks_manager
+
+    def create_media_manager(self):
+        """
+        Creates instance of hte media manager used by the project
+        :return: ArtellaMediaManager
+        """
+
+        media_manager = artellapipe.MediaMgr()
+        media_manager.set_project(self)
+
+        return media_manager
+
     def create_playblasts_manager(self):
         """
        Creates instance of the playblasts manager used by the project
@@ -591,6 +647,39 @@ class ArtellaProject(object):
 
         return pyblish_manager
 
+    def create_dependencies_manager(self):
+        """
+        Crates instance of the dependencies manager used by the project
+        :return: ArtellaDependenciesManager
+        """
+
+        deps_manager = artellapipe.DepsMgr()
+        deps_manager.set_project(self)
+
+        return deps_manager
+
+    def create_casting_manager(self):
+        """
+        Crates instance of the casting manager used by the project
+        :return: ArtellaCastingManager
+        """
+
+        casting_manager = artellapipe.CastMgr()
+        casting_manager.set_project(self)
+
+        return casting_manager
+
+    def create_slack_manager(self):
+        """
+        Crates instance of the slack manager used by the project
+        :return: SlackManager
+        """
+
+        slack_manager = artellapipe.SlackMgr()
+        slack_manager.set_project(self)
+
+        return slack_manager
+
     def create_production_tracker(self):
         """
         Creates instance of the production tracker used by the project
@@ -623,6 +712,23 @@ class ArtellaProject(object):
                 paths_to_return.append(path_utils.clean_path(os.path.join(self.get_project_path(), p)))
             return paths_to_return
 
+    def get_temporary_environment_variable(self):
+        """
+        Returns environment variable used to store temporally path of the project
+        :return: str
+        """
+
+        return '{}_TEMP'.format(self.get_clean_name().upper())
+
+    def get_temporary_folder(self):
+        """
+        Returns path where temporally folder for current folder is located
+        :return: str
+        """
+
+        temp_env = self.get_temporary_environment_variable()
+        return os.environ[temp_env]
+
     def message(self, msg, title=None):
         """
         Shows tray given message in OS tray. If tray is not available, the message will be
@@ -696,6 +802,15 @@ class ArtellaProject(object):
 
         webbrowser.open("mailto:%s?subject=%s" % (','.join(self.emails), quote(title)))
 
+    def notify(self, title, msg):
+        """
+        Notifies given message to the user
+        :param title: str
+        :param msg:
+        """
+
+        self.tray.show_message(title=title, msg=msg)
+
     # ==========================================================================================================
     # PROJECT
     # ==========================================================================================================
@@ -732,6 +847,39 @@ class ArtellaProject(object):
 
         return os.environ.get(self.env_var)
 
+    def get_drive(self):
+        """
+        Returns drive Artella project is located
+        :return: str
+        """
+
+        project_path = self.get_path()
+        if not project_path or not os.path.isdir(project_path):
+            LOGGER.warning(
+                'Impossible to retrieve project path drive because project path does not exists: "{}"'.format(
+                    project_path))
+            return None
+
+        path_split = os.path.splitdrive(project_path)
+
+        return path_split[0]
+
+    def get_production_folder_name(self):
+        """
+        Returns production folder name of current project
+        :return: str
+        """
+
+        return artella_lib.config.get('server', 'production_folder_name')
+
+    def get_production_folder(self):
+        """
+        Returns production folder of current project
+        :return: str
+        """
+
+        return artella_lib.config.get('server', 'production_folder')
+
     def get_production_path(self):
         """
         Returns path where Production data for current project is stored
@@ -743,7 +891,7 @@ class ArtellaProject(object):
             LOGGER.warning('Impossible to retrieve productoin path because Artella project is not setup!')
             return
 
-        production_folder_name = artella_lib.config.get('server', 'production_folder_name')
+        production_folder_name = self.get_production_folder_name()
         return path_utils.clean_path(os.path.join(project_path, production_folder_name))
 
     def get_artella_url(self):
@@ -770,7 +918,7 @@ class ArtellaProject(object):
 
         try:
             if tp.is_maya():
-                import tpMayaLib as maya
+                import tpDcc.dccs.maya as maya
                 LOGGER.debug('Setting {} Project ...'.format(self.name))
                 project_folder = os.environ.get(self.env_var, 'folder-not-defined')
                 if project_folder and os.path.exists(project_folder):
@@ -830,7 +978,7 @@ class ArtellaProject(object):
             return False
 
         if tp.is_maya():
-            from tpMayaLib.core import helpers
+            from tpDcc.dccs.maya.core import helpers
             helpers.clean_student_line()
 
         if notify:
@@ -842,57 +990,6 @@ class ArtellaProject(object):
     # ASSETS
     # ==========================================================================================================
 
-    @decorators.timestamp
-    def get_scene_assets(self, as_nodes=True, allowed_types=None):
-        """
-        Returns a list with all nodes in the current scene
-        :return: list
-        """
-
-        asset_nodes = list()
-
-        abc_nodes = self.get_alembics(as_asset_nodes=False, only_roots=True)
-
-        tag_data_nodes = artellapipe.TagsMgr().get_tag_data_nodes(project=self, as_tag_nodes=True)
-        for tag_data in tag_data_nodes:
-            asset_node = tag_data.get_asset_node()
-            if asset_node is None or asset_node in abc_nodes:
-                continue
-            if allowed_types:
-                asset_types = tag_data.get_types()
-                allow = [i for i in asset_types if i in allowed_types]
-                if allow:
-                    if as_nodes:
-                        asset_nodes.append(asset_node)
-                    else:
-                        asset_nodes.append(asset_node.name)
-            else:
-                if as_nodes:
-                    asset_nodes.append(asset_node)
-                else:
-                    asset_nodes.append(asset_node.name)
-
-        tag_info_nodes = self.get_tag_info_nodes(as_tag_nodes=True)
-        for tag_info in tag_info_nodes:
-            asset_node = tag_info.get_asset_node()
-            if not asset_node:
-                continue
-            if allowed_types:
-                asset_types = tag_info.get_types()
-                allow = [i for i in asset_types if i in allowed_types]
-                if allow:
-                    if as_nodes:
-                        asset_nodes.append(asset_node)
-                    else:
-                        asset_nodes.append(asset_node.name)
-            else:
-                if as_nodes:
-                    asset_nodes.append(asset_node)
-                else:
-                    asset_nodes.append(asset_node.name)
-
-        return asset_nodes
-
     def get_alembics(self, as_asset_nodes=True, only_roots=True):
         """
         Returns all alembic nodes in the scene
@@ -921,9 +1018,9 @@ class ArtellaProject(object):
                 if tp.Dcc.attribute_exists(cnt_root, defines.ARTELLA_TAG_INFO_ATTRIBUTE_NAME):
                     if as_asset_nodes:
                         if only_roots:
-                            all_abc_roots.append(self.ASSET_NODE_CLASS(project=self, node=cnt_root))
+                            all_abc_roots.append(artellapipe.AssetNode(project=self, node=cnt_root))
                         else:
-                            all_abc_roots.append((self.ASSET_NODE_CLASS(project=self, node=cnt_root), abc))
+                            all_abc_roots.append((artellapipe.AssetNode(project=self, node=cnt_root), abc))
                     else:
                         if only_roots:
                             all_abc_roots.append(cnt_root)
@@ -943,66 +1040,6 @@ class ArtellaProject(object):
 
         return all_cameras
 
-    # ==========================================================================================================
-    # SEQUENCES
-    # ==========================================================================================================
-
-    @decorators.timestamp
-    def get_sequences(self, force_update=False):
-        """
-        Returns a list of current sequences in Artella
-        :param force_update: bool
-        :return: list(ArtellaSequence)
-        """
-
-        if self._sequences and not force_update:
-            return self._sequences
-
-        if self._production_info and not force_update:
-            production_info = self._production_info
-        else:
-            production_info = self._update_production_info()
-        if not production_info:
-            return
-
-        sequences_dict = dict()
-        sequences_names = dict()
-        for ref_name, ref_data in production_info.references.items():
-            if not ref_data.is_directory:
-                continue
-            rel_path = self.relative_path(ref_data.path)
-            parse_data = self.parse_template('sequence', rel_path)
-            if not parse_data:
-                continue
-            seq_id = parse_data['sequence_index']
-            seq_name = parse_data['sequence_name']
-            if seq_id in sequences_dict:
-                LOGGER.warning('Sequence with name: {} is duplicated. Skipping ...'.format(seq_name))
-                continue
-            sequences_dict[seq_id] = ref_data
-            sequences_names[seq_id] = seq_name
-
-        valid_index_sequences = dict()
-        not_index_sequences = dict()
-        for seq_id in sequences_dict.keys():
-            try:
-                int_id = int(seq_id)
-                valid_index_sequences[seq_id] = sequences_dict[seq_id]
-            except Exception:
-                not_index_sequences[seq_id] = sequences_dict[seq_id]
-
-        sequences_ordered = OrderedDict(sorted(valid_index_sequences.items(), key=lambda x: int(x[0])))
-        for seq_id in not_index_sequences.keys():
-            sequences_ordered[seq_id] = not_index_sequences[seq_id]
-
-        for seq_id, seq_data in sequences_ordered.items():
-            seq_name = sequences_names[seq_id]
-            new_sequence = self.SEQUENCE_CLASS(
-                project=self, sequence_name=seq_name, sequence_id=seq_id, sequence_data=seq_data)
-            self._sequences.append(new_sequence)
-
-        return self._sequences
-
     # ==========================================================================================================
     # PRIVATE
     # ==========================================================================================================
@@ -1024,74 +1061,6 @@ class ArtellaProject(object):
 
         return ArtellaProjectSettings(project=self, filename=self.get_settings_file())
 
-    def _format_path(self, format_string, path='', **kwargs):
-        """
-        Resolves the given string with the given path and keyword arguments
-        :param format_string: str
-        :param path: str
-        :param kwargs: dict
-        :return: str
-        """
-
-        LOGGER.debug('Format String: {}'.format(format_string))
-
-        dirname, name, extension = path_utils.split_path(path)
-        encoding = locale.getpreferredencoding()
-        temp = tempfile.gettempdir()
-        if temp:
-            temp = temp.decode(encoding)
-
-        username = osplatform.get_user().lower()
-        if username:
-            username = username.decode(encoding)
-
-        local = os.getenv('APPDATA') or os.getenv('HOME')
-        if local:
-            local = local.decode(encoding)
-
-        kwargs.update(os.environ)
-
-        labels = {
-            "name": name,
-            "path": path,
-            "user": username,
-            "temp": temp,
-            "local": local,
-            "dirname": dirname,
-            "extension": extension,
-        }
-
-        kwargs.update(labels)
-
-        resolved_string = six.u(str(format_string)).format(**kwargs)
-
-        LOGGER.debug('Resolved string: {}'.format(resolved_string))
-
-        return path_utils.clean_path(resolved_string)
-
-    def _update_production_info(self):
-        """
-        Internal callback function that updates current production info of the project
-        :return: ArtellaDirectoryMetaData
-        """
-
-        production_path = self.get_production_path()
-        if not production_path:
-            LOGGER.warning(
-                'Impossible to retrieve sequences because Production path for {} is not valid: {}!'.format(
-                    self.name.title(), production_path))
-            return
-
-        production_info = artellalib.get_status(production_path)
-        if not production_info:
-            LOGGER.warning('Impossible to retrieve sequences data from Artella server!')
-            return
-        if not isinstance(production_info, artellaclasses.ArtellaDirectoryMetaData):
-            LOGGER.warning('Error while retrieving Sequences info from Artella!')
-            return
-
-        return production_info
-
     def _update_dcc_ui(self):
         """
         Internal function that updates DCC update taking into account different project attributes
